import { SpaceProps, ColorProps, SizeProps, LayoutProps, FlexboxProps, BorderProps, PositionProps, ShadowProps } from 'styled-system';
/**
 * Prop Types of an Button component.
 * Apart from those defined below it extends all {@link SpaceProps}, {@link ColorProps}
 * {@link SizeProps}, {@link LayoutProps}, {@link FlexboxProps}, {@link PositionProps}
 * {@link BorderProps} and {@link ShadowProps}.
 *
 * @memberof Box
 * @alias BoxProps
 * @property {string} [...] Other props from {@link SpaceProps}, {@link ColorProps}
 *                          {@link SizeProps}, {@link LayoutProps}, {@link FlexboxProps},
 *                          {@link PositionProps} and {@link BorderProps}
 */
export declare type BoxProps = SpaceProps & ColorProps & SizeProps & LayoutProps & Omit<FlexboxProps, 'flex'> & BorderProps & PositionProps & ShadowProps & {
    /** If box should be rendered as flex */
    flex?: boolean;
    /** Box variants */
    variant?: 'grey' | 'white';
    animate?: boolean;
};
/**
 * Main component which allows you to define entire layout of the application
 *
 * @component
 * @subcategory Atoms
 * @example <caption>Simple White/Gray wrapper</caption>
 * return (
 * <Box variant="grey">
 *   <Box variant="white">
 *     <Text>This is the default wrapper in the application</Text>
 *   </Box>
 * </Box>
 * )
 * @example <caption>Positioning buttons</caption>
 * return (
 * <Box variant="grey">
 *   <Box variant="white" flex flexDirection="row">
 *     <Box flexGrow={1}>
 *       <Header.H3>Some header</Header.H3>
 *     </Box>
 *     <Box flexShrink={0}>
 *       <Button>Example Button On The Right</Button>
 *     </Box>
 *   </Box>
 * </Box>
 * )
 */
export declare const Box: import("styled-components").StyledComponent<"section", import("styled-components").DefaultTheme, BoxProps, never>;
export default Box;
